Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(631)

Unified Diff: third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMasker.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMasker.cpp
diff --git a/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMasker.cpp b/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMasker.cpp
index 70c223220cd8c83c6950a886ab833b5767b2d81f..68e53aa320edce2fb1537b220e743badb47b7d1a 100644
--- a/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMasker.cpp
+++ b/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMasker.cpp
@@ -71,7 +71,7 @@ sk_sp<const SkPicture> LayoutSVGResourceMasker::createContentPicture(
SubtreeContentTransformScope contentTransformScope(contentTransformation);
// Using strokeBoundingBox instead of paintInvalidationRectInLocalCoordinates
// to avoid the intersection with local clips/mask, which may yield incorrect
// results when mixing objectBoundingBox and userSpaceOnUse units.
// http://crbug.com/294900
@@ -103,7 +103,7 @@ sk_sp<const SkPicture> LayoutSVGResourceMasker::createContentPicture(
return m_maskContentPicture;
}
-void LayoutSVGResourceMasker::calculateMaskContentPaintInvalidationRect() {
+void LayoutSVGResourceMasker::calculateMaskContentVisualRect() {
for (SVGElement* childElement = Traversal<SVGElement>::firstChild(*element());
childElement;
childElement = Traversal<SVGElement>::nextSibling(*childElement)) {
@@ -116,7 +116,7 @@ void LayoutSVGResourceMasker::calculateMaskContentPaintInvalidationRect() {
continue;
m_maskContentBoundaries.unite(
layoutObject->localToSVGParentTransform().mapRect(
- layoutObject->paintInvalidationRectInLocalSVGCoordinates()));
+ layoutObject->visualRectInLocalSVGCoordinates()));
}
}
@@ -135,7 +135,7 @@ FloatRect LayoutSVGResourceMasker::resourceBoundingBox(
return maskBoundaries;
if (m_maskContentBoundaries.isEmpty())
- calculateMaskContentPaintInvalidationRect();
+ calculateMaskContentVisualRect();
FloatRect maskRect = m_maskContentBoundaries;
if (maskElement->maskContentUnits()->currentValue()->value() ==
@@ -71,7 +71,7 @@ sk_sp<const SkPicture> LayoutSVGResourceMasker::createContentPicture(
SubtreeContentTransformScope contentTransformScope(contentTransformation);
- // Using strokeBoundingBox instead of paintInvalidationRectInLocalCoordinates
+ // Using strokeBoundingBox instead of visualRectInLocalCoordinates
// to avoid the intersection with local clips/mask, which may yield incorrect
// results when mixing objectBoundingBox and userSpaceOnUse units.

Powered by Google App Engine
This is Rietveld 408576698